

ColorSelector = class( Turbine.UI.Label );

function ColorSelector:Constructor(colorList, rgbList, updateFunction)
	Turbine.UI.Label.Constructor( self );    	
	self:SetSize( 200, 20 );
	self.colorList = colorList;
	self.rgbList = rgbList;
	
	self.colorDropDown = DropDown.Create(colorList, colorList[selectedId or 1]); 
	self.colorDropDown:SetParent(self);
	self.colorDropDown:SetPosition(0, 0);
	self.colorDropDown.myElementList = elementList;
	self.colorDropDown:ApplyWidth(110);
	self.colorDropDown:SetMaxItems(table.getn(colorList));
	self.colorDropDown:SetVisible(true);
	self.colorDropDown.ItemChanged = function ()
		for i=1, table.getn(colorList), 1 do
			if(colorList[i]==self.colorDropDown:GetText()) then
				if(i<table.getn(colorList)) then				
					self.colorArea:SetText(rgbList[i]);
					self.colorArea:SetEnabled(false);
					--self.colorArea:SetVisible(false);
					self.selectedColor = self.colorDropDown:GetText();
					self.colorPreview:SetVisible(true);
				else
					self.selectedColor = self.colorDropDown:GetText();
					self.colorArea:SetText(nil);
					--self.colorPreview:SetVisible(false);
					self.colorArea:SetEnabled(true);
					self.colorArea:SetVisible(true);
					self:UpdatePreview();
				end
				self:GetParent():UpdateValidationButton();
				self:UpdatePreview();
				break;
			end
		end	
		self:UpdatePreview();
	end
	self.colorArea = Turbine.UI.Lotro.TextBox();
	self.colorArea:SetParent( self );
	self.colorArea:SetSize( 60, 20 );
	self.colorArea:SetPosition(115, 0);
	self.colorArea:SetMultiline(false);
	self.colorArea:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter );
	self.colorArea:SetText();
	self.colorArea:SetEnabled(selectedId==table.getn(colorList)-1);
	self.colorArea:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.colorArea.TextChanged = function ()
		self:UpdatePreview();
	end
	self.colorArea.FocusLost = function ()
		if(self.colorArea:IsEnabled()==false) then return; end
		if(string.len(self.colorArea:GetText())~=6) then
			Turbine.Shell.WriteLine(_("ERROR_6DIGIT"));
			self.colorArea:SetText("FFFFFF");
			self.colorPreview:SetVisible(true);
			self:UpdatePreview();
		else
			for i=1, 6, 1 do
				local c = string.byte(self.colorArea:GetText(), i);
				if(not ((c>=48 and c<=57) or (c>=65 and c<=70) or (c>=97 and c<=102) )) then
					Turbine.Shell.WriteLine(_("ERROR_NOTHEXA"));
					self.colorArea:SetText("FFFFFF");
					self:UpdatePreview();
				end
			end
		end
		self:GetParent():UpdateValidationButton();
		self:UpdatePreview();
	end	
	self.colorPreview = Turbine.UI.Lotro.TextBox();
	self.colorPreview:SetParent( self );
	self.colorPreview:SetSize( 20, 20 );
	self.colorPreview:SetPosition(180, 0);	
	self.colorPreview:SetEnabled(false);	
	
end

function ColorSelector:SetRGB(rgb)	
	if(rgb==nil or rgb=="") then rgb=self.rgbList[1]; end
	
	self.colorArea:SetText(rgb);
	
	for i=1, table.getn(self.rgbList), 1 do
		if(self.rgbList[i]==rgb) then
			self.colorDropDown:SetLabel(self.colorList[i]);
			self:UpdatePreview();
			return;
		end
	end
	self.colorDropDown:SetLabel(self.colorList[table.getn(self.colorList)]);
	self:UpdatePreview();
end

function ColorSelector:UpdatePreview()
	if(string.len(self.colorArea:GetText())~=6) then 
		self.colorPreview:SetVisible(false);	
		return;
	end
	local r = self:GetByte(self.colorArea:GetText(), 1);
	local g = self:GetByte(self.colorArea:GetText(), 2);
	local b = self:GetByte(self.colorArea:GetText(), 3);
	if(r~=nil and r>=0 and r<=256 and g~=nil and g>=0 and g<=256 and b~=nil and b>=0 and b<=256) then
		self.colorPreview:SetBackColor(Turbine.UI.Color(r/255, g/255, b/255));
		self.colorPreview:SetVisible(true);
	else
		self.colorPreview:SetVisible(false);		
	end
	
end

function ColorSelector:GetRGB()	
	return self.colorArea:GetText();
end

function ColorSelector:GetByte(rgb, w)
	local c1 = string.byte(self.colorArea:GetText(), 1+(w-1)*2);
	local c2 = string.byte(self.colorArea:GetText(), 1+(w-1)*2+1);
	
	local val1 = 0; local val2=0;
	if(c2>=48 and c2<=57) then
		val2 = c2-48;
	elseif(c2>=65 and c2<=70) then
		val2 = 10+c2-65;
	elseif(c2>=97 and c2<=102) then
		val2 = 10+c2-97;
	end
	if(c1>=48 and c1<=57) then
		val1 = c1-48;
	elseif(c1>=65 and c1<=70) then
		val1 = 10+c1-65;
	elseif(c1>=97 and c1<=102) then
		val1 = 10+c1-97;
	end	
	return 16*val1+val2;
end